draw_cpu_usage_block

Function draw_cpu_usage_block 

pub fn draw_cpu_usage_block(
    readings: &Vec<Measurement>,
    f: &mut Frame<'_>,
    area: Rect,
)
Draw the cpu usage block to the given frame.

The CPU usage block is a scrollable block element that contains usage stats for current cpus.