pub struct UIState { /* private fields */ }Expand description
Contains the current ui state of the application.
To create a shareable reference to an instance of this struct, use
new_shared(), which will create an arcmutex around a new struct instance.